==> green-core-1.70.1.tgz: package/utils/global-styles.js <==
import {
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../chunks/chunk.QTSIPXV3.js";
var _useLegacyStylesheets, _styleSheets, _legacyStyleSheets, _initialStyleSheets, _injectStylesLegacy, injectStylesLegacy_fn, _injectStyles, injectStyles_fn;
import { supportsConstructedStylesheets } from "../utils/controllers/dynamic-styles-controller";
import { isServer } from "./helpers/is-server";
function getDocumentAdoptedStylesheet() {
  if (isServer)
    return [];
  return document.adoptedStyleSheets || [];
}
const _GlobalStylesRegistry = class _GlobalStylesRegistry {
  constructor() {
    __privateAdd(this, _injectStylesLegacy);
    __privateAdd(this, _injectStyles);
    __privateAdd(this, _useLegacyStylesheets, !supportsConstructedStylesheets());
    __privateAdd(this, _styleSheets, /* @__PURE__ */ new Map());
    __privateAdd(this, _legacyStyleSheets, /* @__PURE__ */ new Map());
    __privateAdd(this, _initialStyleSheets, getDocumentAdoptedStylesheet());
  }
  /**
   * Get the global singleton instance of the GlobalStylesRegistry.
   */
  static get instance() {
    if (!globalThis.__gdsGlobalStylesRegistry)
      globalThis.__gdsGlobalStylesRegistry = new _GlobalStylesRegistry();
    return globalThis.__gdsGlobalStylesRegistry;
  }
  /**
   * Injects global styles into the document. This function is intended to be used for global styles
   * that cannot be scoped to a specific component.
   *
   * @param key unique identifier for this stylesheet.
   * @param styles CSSResult produced by the lit css template literal tag
   */
  injectGlobalStyles(key, styles) {
    if (__privateGet(this, _useLegacyStylesheets)) {
      const cssText = Array.isArray(styles) ? styles.map((style) => style.toString()).join("") : styles.toString();
      __privateMethod(this, _injectStylesLegacy, injectStylesLegacy_fn).call(this, key, cssText);
    } else {
      styles.styleSheet && __privateMethod(this, _injectStyles, injectStyles_fn).call(this, key, styles.styleSheet);
    }
  }
};
_useLegacyStylesheets = new WeakMap();
_styleSheets = new WeakMap();
_legacyStyleSheets = new WeakMap();
_initialStyleSheets = new WeakMap();
_injectStylesLegacy = new WeakSet();
injectStylesLegacy_fn = function(key, cssText) {
  if (isServer)
    return;
  let styleEl = __privateGet(this, _legacyStyleSheets).get(key);
  if (!styleEl) {
    styleEl = document.createElement("style");
    __privateGet(this, _legacyStyleSheets).set(key, styleEl);
  }
  styleEl.textContent = cssText;
  document.head.appendChild(styleEl);
};
_injectStyles = new WeakSet();
injectStyles_fn = function(key, styleSheet) {
  if (isServer)
    return;
  __privateGet(this, _styleSheets).set(key, styleSheet);
  document.adoptedStyleSheets = [
    ...__privateGet(this, _initialStyleSheets),
    ...Array.from(__privateGet(this, _styleSheets).values())
  ];
};
let GlobalStylesRegistry = _GlobalStylesRegistry;
export {
  GlobalStylesRegistry
};

==> green-core-1.76.1.tgz: package/utils/global-styles.js <==
import {
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../chunks/chunk.QTSIPXV3.js";
var _useLegacyStylesheets, _styleSheets, _legacyStyleSheets, _initialStyleSheets, _injectStylesLegacy, injectStylesLegacy_fn, _injectStyles, injectStyles_fn;
import { supportsConstructedStylesheets } from "../utils/controllers/dynamic-styles-controller.js";
import { isServer } from "./helpers/is-server.js";
function getDocumentAdoptedStylesheet() {
  if (isServer)
    return [];
  return document.adoptedStyleSheets || [];
}
const _GlobalStylesRegistry = class _GlobalStylesRegistry {
  constructor() {
    __privateAdd(this, _injectStylesLegacy);
    __privateAdd(this, _injectStyles);
    __privateAdd(this, _useLegacyStylesheets, !supportsConstructedStylesheets());
    __privateAdd(this, _styleSheets, /* @__PURE__ */ new Map());
    __privateAdd(this, _legacyStyleSheets, /* @__PURE__ */ new Map());
    __privateAdd(this, _initialStyleSheets, getDocumentAdoptedStylesheet());
  }
  /**
   * Get the global singleton instance of the GlobalStylesRegistry.
   */
  static get instance() {
    if (!globalThis.__gdsGlobalStylesRegistry)
      globalThis.__gdsGlobalStylesRegistry = new _GlobalStylesRegistry();
    return globalThis.__gdsGlobalStylesRegistry;
  }
  /**
   * Injects global styles into the document. This function is intended to be used for global styles
   * that cannot be scoped to a specific component.
   *
   * @param key unique identifier for this stylesheet.
   * @param styles CSSResult produced by the lit css template literal tag
   */
  injectGlobalStyles(key, styles) {
    if (__privateGet(this, _useLegacyStylesheets)) {
      const cssText = Array.isArray(styles) ? styles.map((style) => style.toString()).join("") : styles.toString();
      __privateMethod(this, _injectStylesLegacy, injectStylesLegacy_fn).call(this, key, cssText);
    } else {
      styles.styleSheet && __privateMethod(this, _injectStyles, injectStyles_fn).call(this, key, styles.styleSheet);
    }
  }
};
_useLegacyStylesheets = new WeakMap();
_styleSheets = new WeakMap();
_legacyStyleSheets = new WeakMap();
_initialStyleSheets = new WeakMap();
_injectStylesLegacy = new WeakSet();
injectStylesLegacy_fn = function(key, cssText) {
  if (isServer)
    return;
  let styleEl = __privateGet(this, _legacyStyleSheets).get(key);
  if (!styleEl) {
    styleEl = document.createElement("style");
    __privateGet(this, _legacyStyleSheets).set(key, styleEl);
  }
  styleEl.textContent = cssText;
  document.head.appendChild(styleEl);
};
_injectStyles = new WeakSet();
injectStyles_fn = function(key, styleSheet) {
  if (isServer)
    return;
  __privateGet(this, _styleSheets).set(key, styleSheet);
  document.adoptedStyleSheets = [
    ...__privateGet(this, _initialStyleSheets),
    ...Array.from(__privateGet(this, _styleSheets).values())
  ];
};
let GlobalStylesRegistry = _GlobalStylesRegistry;
export {
  GlobalStylesRegistry
};
